@@ -15,20 +15,17 @@ use strict;
 #use warnings;    # disabled upon release
 $|++;
 
-use Carp qw/croak cluck/;
 use Net::DNS;
 
 use encoding 'utf8';
 
 sub get_TK_version {
-
     # Stick with %.2f format - 4.50 vice 4.5
-    return '4.26';
+    return '4.27';
 }
 
 sub get_path {
-    shift;    # throw one away
-    my $wanted = shift;
+    my ( undef, $wanted ) = @_;
     my $path;
 
     # These are directories and files necessary for
@@ -77,13 +74,14 @@ sub get_path {
 
     $path->{clamscan} = $path->{clampath};
 
+    # The default ClamAV options:
+    # leave out the summary and warn on encrypted
     $path->{clamscan} .= ' --no-summary --block-encrypted ';
 
     return ( $wanted eq 'all' ) ? $path : $path->{$wanted};
 }
 
 sub def_paths {
-
     # Returns (path_of_daily.c?d, path_of_main.c?d)
     # There are 3 formats:
     # 1. The .cld files
@@ -95,6 +93,7 @@ sub def_paths {
 
     my ( $DAILY_PATH, $MAIN_PATH );
 
+    # These are the typical directories where the sigs are found:
     my @dirs = qw#
         /var/lib/clamav
         /var/clamav
@@ -111,17 +110,17 @@ sub def_paths {
         unshift( @dirs, $paths );
     }
 
+    # We'll search for the daily file then main;
+    # and check for .cld before .cvd
     for my $dir_list (@dirs) {
         if ( -e "$dir_list/daily.cld" ) {
             $DAILY_PATH = "$dir_list/daily.cld";
-        }
-        elsif ( -e "$dir_list/daily.cvd" ) {
+        } elsif ( -e "$dir_list/daily.cvd" ) {
             $DAILY_PATH = "$dir_list/daily.cvd";
         }
         if ( -e "$dir_list/main.cld" ) {
             $MAIN_PATH = "$dir_list/main.cld";
-        }
-        elsif ( -e "$dir_list/main.cvd" ) {
+        } elsif ( -e "$dir_list/main.cvd" ) {
             $MAIN_PATH = "$dir_list/main.cvd";
         }
         last if ( $DAILY_PATH && $MAIN_PATH );
@@ -134,8 +133,9 @@ sub def_paths {
 }
 
 sub get_AV_version {
-
     # simple 'clamscan -V'
+    # We have to parse this:
+    # ClamAV 0.95.3/11220/Fri Jun 18 22:06:39 2010
     my $paths = ClamTk::App->get_path('clampath');
     my ($version) = qx/$paths -V/;
     $version =~ s/ClamAV\s(.*?)\/.*/$1/;
@@ -144,7 +144,6 @@ sub get_AV_version {
 }
 
 sub get_AV_remote {
-
     # The user may have set the preference to not check this
     # on startup using 'AVCheck'
     return 'undef' if ( !ClamTk::Prefs->get_preference('AVCheck') );
@@ -159,6 +158,7 @@ sub get_AV_remote {
     my ( $get, $res );
 
     $res = Net::DNS::Resolver->new( udp_timeout => 3, );
+    # We have permission from OpenDNS to use this. :)
     if ( ClamTk::Prefs->get_preference('OpenDNS') ) {
         $res->nameservers(
             qw(208.67.222.222 208.67.220.220
@@ -178,21 +178,18 @@ sub get_AV_remote {
   # We just need the version, held between the " and the :
     if ( $get->string =~ /IN\s+TXT\s+\"(.*?):/ ) {
         return $1;
-    }
-    else {
+    } else {
         return 'undef';
     }
 }
 
 sub get_num_sigs {
-
     # Adds the main + daily for total # of signatures
     my ( undef, $daily, $main ) = get_sig_info();
     return ( $daily + $main );
 }
 
 sub get_date_sigs {
-
     # Gets the date, preferably from daily.c?d.
     # Useful for informing user of outdated sigs.
     my ( $date, undef, undef ) = get_sig_info();
@@ -200,10 +197,15 @@ sub get_date_sigs {
 }
 
 sub get_sig_info {
+    # This sub parses the signature files for the date
+    # and number of signatures.
     my ( $daily_path, $main_path ) = def_paths();
-    cluck "I'm missing daily.{cld,cvd} and/or main.{cld,cvd}.\n"
-        unless ( $daily_path && $main_path );
+    #warn "I'm missing daily.{cld,cvd} and/or main.{cld,cvd}.\n"
+    #    unless ( $daily_path && $main_path );
 
+    # $INFO_DATE = Date of signatures
+    # $INFO_DAILY = # of 'daily' signatures (not part of main.{cld,cvd})
+    # $INFO_MAIN = # of signatures part of 'main' signatures
     my ( $INFO_DATE, $INFO_DAILY, $INFO_MAIN );
 
     # example of what we need to parse
@@ -225,12 +227,10 @@ sub get_sig_info {
                 close($FILE)
                     or warn "Couldn't close $main_path: $!\n";
             }
-        }
-        else {
+        } else {
             $INFO_MAIN = 0;
         }
-    }
-    else {
+    } else {
         $INFO_MAIN = 0;
     }
 
@@ -247,8 +247,7 @@ sub get_sig_info {
             }
             close($FILE)
                 or warn "Couldn't close $daily_path: $!\n";
-        }
-        else {
+        } else {
             $INFO_DATE  = '01 Jan 1970';
             $INFO_DAILY = 0;
         }
