@@ -17,8 +17,6 @@ $|++;
 
 use ClamTk::App;
 
-use Carp qw(cluck croak);
-
 use encoding 'utf8';
 
 use File::Path;
@@ -34,50 +32,68 @@ sub structure {
     # Ensure default paths/files exist.
     # If they do, ensure they have the proper permissions
     if ( !-d $paths->{viruses} ) {
+        # This is typically /home/user/.clamtk/viruses,
+        # used for the quarantine directory
         eval { mkpath( $paths->{viruses}, 0, oct(755) ); };
         return 0 if ($@);
-    }
-    else {
+    } else {
+        # Ensure the permissions are correct
         chmod oct(755), $paths->{viruses};
     }
     if ( !-d $paths->{history} ) {
+        # This is typically /home/user/.clamtk/history,
+        # which holds records of scans
         eval { mkpath( $paths->{history}, 0, oct(755) ); };
         return 0 if ($@);
-    }
-    else {
+    } else {
+        # Ensure the permissions are correct
         chmod oct(755), $paths->{history};
     }
     if ( !-d $paths->{db} ) {
+        # This is typically /home/user/.clamtk/db
         eval { mkpath( $paths->{db}, 0, oct(755) ); };
-        cluck $@ if $@;
+        warn $@  if $@;
         return 0 if ($@);
-    }
-    else {
+    } else {
+        # Ensure the permissions are correct
         chmod oct(755), $paths->{db};
     }
     if ( !-e $paths->{prefs} ) {
+        # This is /home/user/.clamtk/prefs,
+        # a custom INI-style file
         open( my $F, ">:encoding(UTF-8)", $paths->{prefs} )
-            or croak "Unable to create preferences! $!\n";
+            or do {
+            warn "Unable to create preferences! $!\n";
+            return 0;
+            };
         close($F);
         eval { custom_prefs() };
         return 0 if ($@);
     }
     if ( !-e $paths->{restore} ) {
+        # This is /home/user/.clamtk/restore, which holds
+        # information for putting back false positives
         open( my $F, ">:encoding(UTF-8)", $paths->{restore} )
-            or croak "Unable to create restore file! $!\n";
+            or do {
+            warn "Unable to create restore file! $!\n";
+            return 0;
+            };
         close($F);
     }
     return 1;
 }
 
 sub custom_prefs {
+   # ensure prefs have normalized variables, especially for 3.11 -> 4.00 users
     my %pkg;
-
+    # Get the user's current prefs
     my $paths = ClamTk::App->get_path('prefs');
 
-   # ensure prefs have normalized variables, especially for 3.11 -> 4.00 users
     open( my $F, "<:encoding(UTF-8)", $paths )
-        or croak "Unable to read preferences! $!\n";
+        or do {
+        warn "Unable to read preferences! $!\n";
+        return 0;
+        };
 
     while (<$F>) {
         my ( $k, $v ) = split(/=/);
@@ -86,20 +102,22 @@ sub custom_prefs {
     }
     close($F);
 
+    # If the preferences aren't already set,
+    # use 'shared' by default. This makes it work out of the box.
     if ( !exists $pkg{Update} ) {
         $pkg{Update} = 'shared';
-    }
-    elsif ( $pkg{Update} !~ /shared|single/ ) {
-
+    } elsif ( $pkg{Update} !~ /shared|single/ ) {
         # If it's set to 'shared' or 'single', leave it alone.
         # Otherwise, look for system signatures.
         $pkg{Update} = 'shared';
     }
 
+    # The proxy is off by default
     if ( !exists $pkg{HTTPProxy} ) {
         $pkg{HTTPProxy} = 0;
     }
 
+    # The whitelist is off by default
     if ( !exists $pkg{Whitelist} ) {
         $pkg{Whitelist} = '';
     }
@@ -130,10 +148,15 @@ sub custom_prefs {
 }
 
 sub get_all_prefs {
+    # Sometimes it's useful to have all
+    # the preferences rather than just one.
     my %pkg;
     my $paths = ClamTk::App->get_path('prefs');
     open( my $F, "<:encoding(UTF-8)", $paths )
-        or croak "Unable to read preferences! $!\n";
+        or do {
+        warn "Unable to read preferences! $!\n";
+        return 0;
+        };
 
     while (<$F>) {
         my ( $k, $v ) = split(/=/);
@@ -149,7 +172,10 @@ sub write_all {
 
     my $paths = ClamTk::App->get_path('prefs');
     open( my $F, ">:encoding(UTF-8)", $paths )
-        or croak "Unable to write preferences! $!\n";
+        or do {
+        warn "Unable to write preferences! $!\n";
+        return 0;
+        };
 
     while ( my ( $k, $v ) = each %loc ) {
         print $F "$k=$v\n";
@@ -164,7 +190,10 @@ sub set_preference {
     my $paths = ClamTk::App->get_path('prefs');
 
     open( my $F, "<:encoding(UTF-8)", $paths )
-        or croak "Unable to read preferences! $!\n";
+        or do {
+        warn "Unable to read preferences! $!\n";
+        return 0;
+        };
 
     my %pkg;
     while (<$F>) {
@@ -192,7 +221,10 @@ sub get_preference {
     my $paths = ClamTk::App->get_path('prefs');
     my %pkg;
     open( my $F, "<:encoding(UTF-8)", $paths )
-        or croak "Unable to read preferences! $!\n";
+        or do {
+        warn "Unable to read preferences! $!\n";
+        return 0;
+        };
 
     while (<$F>) {
         my ( $k, $v ) = split(/=/);
@@ -207,12 +239,13 @@ sub get_preference {
 
 sub set_proxy {
     my ( undef, $ip, $port ) = @_;    # undef = package name
+           # If the user doesn't set a port, we'll just jot down port 80.
     $port = $port || '80';
 
     my $path = ClamTk::App->get_path('db');
 
     # I'm going to clobber this every time.
-    # Doesn't need to be utf-8 friendly
+    # Doesn't need to be utf-8 friendly. I think.
     open( my $FH, '>', "$path/local.conf" )
         or return -1;
     print $FH <<"EOF";
@@ -231,7 +264,7 @@ sub restore {
     my $wanted = shift;    # the md5sum of the file we're after
     my $job    = shift;    # either exists, add, or remove
     my $path   = shift;    # full path of file
-    my $perm   = shift;    # permissions in octal (0644)
+    my $perm   = shift;    # permissions in octal (eg., 0644)
 
     my %p;
     my $restore_path = ClamTk::App->get_path('restore');
@@ -245,7 +278,6 @@ sub restore {
         chomp;
         my ( $m, $paths, $perms ) = split /:/;
         if ( exists $p{$m} ) {
-
             #warn "File $m already exists?\n";
             return -1;
         }
@@ -265,7 +297,6 @@ sub restore {
 
     if ( $job eq 'add' ) {
         if ( exists( $p{$wanted} ) ) {
-
             #warn "File $wanted already exists?\n";
             return -1;
         }
@@ -300,7 +331,6 @@ sub restore {
 }
 
 sub restore_file_fix {
-
     # This subroutine might only be in 4.25; for some reason the line
     # 'next if ($e eq $wanted)' got dropped from 'sub restore' above.
     # So, we need to remove all the lines from the restore file that
