@@ -18,7 +18,6 @@ $|++;
 use File::Basename;
 use File::Copy;
 use Digest::MD5 qw/md5_hex/;
-use Carp qw/cluck/;
 
 use encoding 'utf8';
 
@@ -75,8 +74,7 @@ sub display {
     $slist->set_rules_hint(TRUE);
     $slist->set_headers_clickable(TRUE);
 
-    # can't be reorderable - messes up the \&row_clicked function
-    $slist->set_reorderable(FALSE);
+    $slist->set_reorderable(TRUE);
     map { $_->set_resizable(TRUE) } $slist->get_columns;
 
     #map { $_->set_fixed_width(250) } $slist->get_columns;
@@ -111,7 +109,8 @@ sub display {
             my $deref = $sel[0];
             defined $deref or return;
 
-            # We have to avoid parsing mail for now
+            # We have to avoid parsing mail for now:
+            # http://clamtk.sourceforge.net/faq.html#inbox
             my $maildirs = join( '|',
                 '.thunderbird', '.mozilla-thunderbird',
                 '.evolution',   'Mail',
@@ -159,7 +158,9 @@ sub display {
                 unless dirname( $hash->{$deref}->{name} )
                     =~ /^\/(proc|sys|dev)/;
 
-            # Right-click 'save-as' option
+            # Right-click 'save-as' option.
+            # This is useful if the file is 'opened' (intercepted)
+            # as a $web_browser download
             my $save_pop =
                 Gtk2::ImageMenuItem->new_from_stock( 'gtk-save-as', undef );
             $save_pop->signal_connect(
@@ -187,8 +188,7 @@ sub display {
                         show_message_dialog( $popup, 'info', 'close',
                             gettext('File saved.') );
                         return FALSE;
-                    }
-                    else {
+                    } else {
                         $save_dialog->destroy();
                     }
                 }
@@ -202,7 +202,6 @@ sub display {
             $cancel_pop->signal_connect( activate => sub { return; } );
             $cancel_pop->show();
             $menu->append($cancel_pop);
-
             $menu->popup( undef, undef, undef, undef, $event->button,
                 $event->time );
 
@@ -213,6 +212,11 @@ sub display {
 }
 
 sub main_confirm {
+    # This sub accepts both quarantine and delete options.
+    # The quarantine happens without prompting, but deleting
+    # always prompts the user.
+    # $number = row of selected file so we can reference it
+    # $do_this = quarantine, delete
     my $number  = shift;
     my $do_this = shift;
 
@@ -220,40 +224,30 @@ sub main_confirm {
     my $status    = $slist->{data}[$number][1];
     my $action    = $slist->{data}[$number][2];
 
-    # do_this = quarantine (q), delete (d), or save (s)
-    if ( $do_this eq "q" ) {
+    # do_this = quarantine (q), delete (d), or save (s).
+    # The #CCCCCC color gives a neat grayed-out look
+    # once the file is quarantined, deleted, or saved
+    if ( $do_this eq 'q' ) {
         if ( not -e $full_name ) {
             $hover_label->set_text(
                 sprintf gettext('File has been moved or deleted already.') );
-            $slist->{data}[$number][0] =
-                "<span foreground='#CCCCCC'>$full_name</span>";
-            $slist->{data}[$number][1] =
-                "<span foreground='#CCCCCC'>$status</span>";
-            $slist->{data}[$number][2] =
-                "<span foreground='#CCCCCC'>$action</span>";
+            main_slist_delete($number);
             return;
         }
         if ( move_to_quarantine($number) ) {
             $hover_label->set_text( gettext('File has been quarantined.') );
             $slist->{data}[$number][2] =
                 sprintf gettext("<b>Quarantined</b>");
-        }
-        else {
+        } else {
             $hover_label->set_text(
                 gettext('File could not be quarantined.') );
             return;
         }
-    }
-    elsif ( $do_this eq "d" ) {
+    } elsif ( $do_this eq 'd' ) {
         if ( not -e $full_name ) {
             $hover_label->set_text(
                 gettext('File has been moved or deleted already.') );
-            $slist->{data}[$number][0] =
-                "<span foreground='#CCCCCC'>$full_name</span>";
-            $slist->{data}[$number][1] =
-                "<span foreground='#CCCCCC'>$status</span>";
-            $slist->{data}[$number][2] =
-                "<span foreground='#CCCCCC'>$action</span>";
+            main_slist_delete($number);
             return;
         }
         my $confirm_message = gettext('Really delete this file?');
@@ -265,22 +259,19 @@ sub main_confirm {
         if ( 'cancel' eq $confirm->run ) {
             $confirm->destroy;
             return;
-        }
-        else {
+        } else {
             $confirm->destroy;
             if ( unlink($full_name) ) {
                 $hover_label->set_text( gettext('File has been deleted.') );
                 $slist->{data}[$number][2] =
                     sprintf gettext("<b>Deleted</b>");
-            }
-            else {
+            } else {
                 $hover_label->set_text(
                     gettext('File could not be deleted.') );
                 return;
             }
         }
-    }
-    elsif ( $do_this eq 's' ) {
+    } elsif ( $do_this eq 's' ) {
         my $new_action = gettext('Moved');
         $slist->{data}[$number][0] =
             "<span foreground='#CCCCCC'>$full_name</span>";
@@ -315,9 +306,8 @@ sub move_to_quarantine {
 
     my $paths = ClamTk::App->get_path('viruses');
 
-    if (   not -e $paths
-        or not -d $paths )
-    {
+    # Ensure quarantine directory exists
+    if ( not -e $paths or not -d $paths ) {
         show_message_dialog( $popup, 'info', 'close',
             gettext('Quarantine directory does not exist.') );
         return;
@@ -328,13 +318,21 @@ sub move_to_quarantine {
     my $perm = sprintf( "%03o", $mode & oct(7777) );
 
     chmod oct(600), $full_name;
-    system( 'mv', $full_name, "$paths/$basename" );
+    system( 'mv', $full_name, "$paths/$basename" ) == 0
+        or do {
+        # When a 'mv' fails, it still probably did a 'cp'...
+        # 'mv' copies the file first, then unlinks the source.
+        # d'oh... so just to make sure, unlink the intended target
+        # and THEN return.  No need to check for failure.
+        unlink("$paths/$basename");
+        return;
+        };
     rename( "$paths/$basename", "$paths/$basename.VIRUS" );
 
     # Update restore file by adding file, path and md5
     my $ctx = Digest::MD5->new;
     open( my $F, '<', "$paths/$basename.VIRUS" ) or do {
-        cluck "Could not open file for md5-ing: $!\n";
+        warn "Could not open file for md5-ing: $!\n";
         return;
     };
     $ctx->addfile(*$F);
@@ -345,8 +343,7 @@ sub move_to_quarantine {
 
     if ( not -e $full_name ) {
         return 1;
-    }
-    else {
+    } else {
         return -1;
     }
 }
