@@ -42,8 +42,7 @@ sub update_dialog {
 
     if ( -e '/usr/share/pixmaps/clamtk.png' ) {
         $win->set_default_icon_from_file('/usr/share/pixmaps/clamtk.png');
-    }
-    elsif ( -e '/usr/share/pixmaps/clamtk.xpm' ) {
+    } elsif ( -e '/usr/share/pixmaps/clamtk.xpm' ) {
         $win->set_default_icon_from_file('/usr/share/pixmaps/clamtk.xpm');
     }
 
@@ -101,7 +100,7 @@ sub update_dialog {
     $hbox->set_layout_default('spread');
     $win->vbox->set_focus_child($hbox);
 
-    my $go_img = Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
+    my $go_img = Gtk2::Image->new_from_stock( 'gtk-redo', 'small-toolbar' );
     $go_btn = Gtk2::Button->new();
     $go_btn->signal_connect( clicked => \&decision );
     $go_btn->set_property( 'image' => $go_img );
@@ -210,21 +209,18 @@ sub decision {
                     : $value == 2  ? gettext('Updated')
                     :                '';
                 ClamTk::GUI->set_sig_status();
-            }
-            elsif ( $rowref->[0] eq gettext('GUI updates') ) {
+            } elsif ( $rowref->[0] eq gettext('GUI updates') ) {
                 $update_list->{data}[$row][3] = gettext('Checking...');
                 $value = update_gui( 'dummy', 'not-startup' );
                 $update_list->{data}[$row][3] =
-                      $value == 1  ? gettext('GUI is current')
-                    : $value == 2  ? gettext('A newer version is available')
-                    : $value == 3  ? gettext('GUI is current')
-                    : $value == 4  ? gettext('Check failed')
-                    : $value == 5  ? gettext('Check failed')
-                    :                '';
+                      $value == 1 ? gettext('GUI is current')
+                    : $value == 2 ? gettext('A newer version is available')
+                    : $value == 3 ? gettext('GUI is current')
+                    : $value == 4 ? gettext('Check failed')
+                    : $value == 5 ? gettext('Check failed')
+                    :               '';
                 ClamTk::GUI->set_tk_status($value);
-            }
-            else {
-
+            } else {
                 #warn 'ref = ', $rowref->[0], "\n";
             }
         }
@@ -297,48 +293,40 @@ sub update_signatures {
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        elsif ( $line =~ /Downloading daily|Retrieving http/ ) {
+        } elsif ( $line =~ /Downloading daily|Retrieving http/ ) {
             $final = gettext('Downloading updates...');
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        elsif ( $line =~ /nonblock_connect|Can't connect to/ ) {
+        } elsif ( $line =~ /nonblock_connect|Can't connect to/ ) {
             $final = gettext('Cannot connect...');
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        elsif ( $line =~ /^daily.c.d updated/ ) {
+        } elsif ( $line =~ /^daily.c.d updated/ ) {
             $final = gettext('Daily signatures have been updated');
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        elsif ( $line =~ /Database updated .(\d+) signatures/ ) {
+        } elsif ( $line =~ /Database updated .(\d+) signatures/ ) {
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
             return 2;
-        }
-        elsif ( $line =~ /daily.c.d is up to date/ ) {
+        } elsif ( $line =~ /daily.c.d is up to date/ ) {
             Gtk2->main_iteration while ( Gtk2->events_pending );
             return 1;
-        }
-        elsif ( $line =~ /main.cvd version from DNS/ ) {
+        } elsif ( $line =~ /main.cvd version from DNS/ ) {
             $final = gettext('Checking main virus database version');
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        elsif ( $line =~ /main.c.d is up to date/ ) {
+        } elsif ( $line =~ /main.c.d is up to date/ ) {
             $final = gettext('Main virus database is current');
             Gtk2->main_iteration while ( Gtk2->events_pending );
             $update_list->{data}[$print_row][3] = $final;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        else {
+        } else {
             next;
         }
         Gtk2->main_iteration while ( Gtk2->events_pending );
@@ -351,13 +339,11 @@ sub update_signatures {
 }
 
 sub update_gui {
-    shift; # throw away package name
-    my $caller = shift;
+    my ( undef, $caller ) = @_;
 
     my ($version) = ClamTk::App->get_TK_version();
 
     if ( $caller and $caller eq 'startup' ) {
-
         # The user may have set the preference ('GUICheck')
         # to not check this on startup
         return -1
@@ -376,8 +362,7 @@ sub update_gui {
     if ( ClamTk::Prefs->get_preference('HTTPProxy') ) {
         if ( ClamTk::Prefs->get_preference('HTTPProxy') == 1 ) {
             $ua->env_proxy;
-        }
-        elsif ( ClamTk::Prefs->get_preference('HTTPProxy') == 2 ) {
+        } elsif ( ClamTk::Prefs->get_preference('HTTPProxy') == 2 ) {
             my $path = ClamTk::App->get_path('db');
             $path .= '/local.conf';
             my ( $url, $port );
@@ -405,14 +390,13 @@ sub update_gui {
         my $content = $response->content;
         chomp($content);
         $content =~ s/[^0-9]//g;
-        return 1 if ( $version == $content ); # current
-        return 2 if ( $content > $version );  # outdated
-        return 3 if ( $version > $content );  # too current?
-        return 4;			      # shouldn't happen
-    }
-    else {
-	# warn $response->as_string, "\n";
-        return 5;			      # failed, unable to check
+        return 1 if ( $version == $content );    # current
+        return 2 if ( $content > $version );     # outdated
+        return 3 if ( $version > $content );     # too current?
+        return 4;                                # shouldn't happen
+    } else {
+        # warn $response->as_string, "\n";
+        return 5;                                # failed, unable to check
     }
 }
 
@@ -424,8 +408,7 @@ sub av_db_select {
 
     if ( -e '/usr/share/pixmaps/clamtk.png' ) {
         $choice->set_default_icon_from_file('/usr/share/pixmaps/clamtk.png');
-    }
-    elsif ( -e "/usr/share/pixmaps/clamtk.xpm" ) {
+    } elsif ( -e '/usr/share/pixmaps/clamtk.xpm' ) {
         $choice->set_default_icon_from_file('/usr/share/pixmaps/clamtk.xpm');
     }
 
@@ -440,6 +423,7 @@ sub av_db_select {
     $sw->set_policy( 'automatic', 'automatic' );
     $sw->set_border_width(5);
 
+    # This is horrible and will be changed in 4.5 or 5.0.
     my $dialog =
         gettext( "\nPlease choose how you will update your antivirus "
             . "signatures.\n\nIf this is a multi-user system or you have an "
@@ -460,14 +444,16 @@ sub av_db_select {
     my $c_box = Gtk2::HButtonBox->new();
     $choice->vbox->pack_start( $c_box, FALSE, FALSE, 0 );
 
+    # The {single,save}_btn buttons are
+    # set sensitive->FALSE when selected.
     my ( $cancel_btn, $single_btn, $sys_btn, $save_btn, $quit_btn, $label );
 
+    # Cancel button
     $cancel_btn = Gtk2::Button->new_from_stock('gtk-cancel');
     $c_box->add($cancel_btn);
-    $cancel_btn->signal_connect(
-	clicked => sub { $choice->destroy }
-    );
+    $cancel_btn->signal_connect( clicked => sub { $choice->destroy } );
 
+    # 'Single' button - user will update
     $single_btn = Gtk2::Button->new( gettext('Single User') );
     $c_box->add($single_btn);
     $single_btn->signal_connect(
@@ -479,6 +465,7 @@ sub av_db_select {
         }
     );
 
+    # 'Shared' button - system updates
     $sys_btn = Gtk2::Button->new( gettext('System Wide') );
     $c_box->add($sys_btn);
     $sys_btn->signal_connect(
@@ -490,6 +477,8 @@ sub av_db_select {
         }
     );
 
+    # 'Save' button - not sensitive until
+    # 'single' or 'shared' is selected
     $save_btn = Gtk2::Button->new_from_stock('gtk-save');
     $c_box->add($save_btn);
     $save_btn->signal_connect(
@@ -504,6 +493,7 @@ sub av_db_select {
     );
     $save_btn->set_sensitive(FALSE);
 
+    # 'Quit' button
     $quit_btn = Gtk2::Button->new_from_stock('gtk-quit');
     $c_box->add($quit_btn);
     $quit_btn->signal_connect( clicked => sub { $choice->destroy } );
@@ -527,8 +517,7 @@ sub save {
     my ($ret) = ClamTk::Prefs->set_preference( 'Update', $update );
 
     if ( $ret == 1 ) {
-
-        # if it worked, see if there are system signatures around
+        # It worked, so see if there are system signatures around
         # we can copy to save bandwidth and time
 
         my $paths = ClamTk::App->get_path('db');
@@ -545,16 +534,14 @@ sub save {
                 if ( -e "$dir_list/daily.cld" ) {
                     system( 'cp', "$dir_list/daily.cld", "$paths/daily.cld" );
                     $d = 1;
-                }
-                elsif ( -e "$dir_list/daily.cvd" ) {
+                } elsif ( -e "$dir_list/daily.cvd" ) {
                     system( 'cp', "$dir_list/daily.cvd", "$paths/daily.cvd" );
                     $d = 1;
                 }
                 if ( -e "$dir_list/main.cld" ) {
                     system( 'cp', "$dir_list/main.cld", "$paths/main.cld" );
                     $m = 1;
-                }
-                elsif ( -e "$dir_list/main.cvd" ) {
+                } elsif ( -e "$dir_list/main.cvd" ) {
                     system( "cp", "$dir_list/main.cvd", "$paths/main.cvd" );
                     $m = 1;
                 }
